from optparse import OptionParser
from pathlib import Path
from odoo_tools.modules.search import find_modules_paths
from odoo_tools.modules.search import get_manifest


def get_parser():
    parser = OptionParser()

    parser.add_option(
        "-p",
        dest='paths',
        action="append",
        help="Location in which to search",
        default=[]
    )

    parser.add_option(
        "--only-name",
        dest="only_name",
        action="store_true",
        help="Only display module name instead of path",
        default=False,
    )

    parser.add_option(
        '--installable',
        dest='installable',
        action="store_true",
        help="Output only installable modules",
        default=False
    )

    parser.add_option(
        '--non-installable',
        dest='non_installable',
        action="store_true",
        help="Output only installable modules",
        default=False
    )

    parser.add_option(
        '--csv',
        dest="is_csv",
        action="store_true",
        help="Output as a comma separated list",
        default=False
    )

    parser.add_option(
        '--without-version',
        dest="without_version",
        action="store_true",
        help="Display only modules without versions",
        default=False
    )

    return parser


def command():
    parser = get_parser()
    (options, args) = parser.parse_args()

    filters = set()

    if options.installable:
        filters.add('installable')

    if options.non_installable:
        filters.add('non_installable')

    modules = find_modules_paths(
        options.paths,
        options.only_name,
        filters=filters
    )

    if not options.is_csv:
        for module in modules:
            if options.without_version:
                manifest = get_manifest(Path(module))
                if 'version' not in manifest:
                    print(module)
            else:
                print(module)
    else:
        print(",".join(modules), end="")
